##
##  fabio.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_fabio      1.6.7
%define       V_fabio_base 1.6.7
%define       V_fabio_snap 20250530

#   package information
Name:         fabio
Summary:      Reverse Proxy Based on Consul
URL:          https://fabiolb.net/
Vendor:       eBay Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_fabio_base}.%{V_fabio_snap}
Release:      20250530

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/fabio/fabio-%{V_fabio_snap}.tar.xz
Source1:      rc.fabio
Source2:      fabio.properties

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Fabio is a fast, zero-config load-balancing reverse proxy for HTTP
    API management and microservices. It uses Consul as a configuration
    backend, so changes to configuration take effect immediately without
    restarting the service.

%track
    prog fabio:release = {
        version   = %{V_fabio_base}
        url       = https://github.com/fabiolb/fabio/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }
    prog fabio:snapshot = {
        version   = %{V_fabio_snap}
        url       = http://download.openpkg.org/components/versioned/fabio/
        regex     = fabio-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n fabio

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/fabiolb/fabio
    go build -v -o fabio .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fabio \
        $RPM_BUILD_ROOT%{l_prefix}/var/fabio/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/fabio/log

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/fabiolb/fabio/fabio \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.fabio} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fabio.properties} $RPM_BUILD_ROOT%{l_prefix}/etc/fabio/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fabio/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/fabio/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} fabio status 2>/dev/null`
        [ ".$fabio_active" = .yes ] && %{l_rc} fabio restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    if [ $1 -eq 0 ]; then
        %{l_rc} fabio stop 2>/dev/null
        rm -f $RPM_INSTALL_PREFIX/var/fabio/log/* >/dev/null 2>&1 || true
        rm -f $RPM_INSTALL_PREFIX/var/fabio/run/* >/dev/null 2>&1 || true
    fi
    exit 0

